Frozen Desert is a Text-Adventure type game that is began as a project to help me learn python, but has since evolved into much more!


In This game you play as an adventurer in the desolate wasteland affectionately referred to as the Frozen Desert by its inhabitants.
In actuality, the Frozen Desert is an ex-colony of the greater 'A sziklák birodalma' (Empire of the Cliffs).
Known as "A dicsőség és a gazdagság kolóniája" (Colony of glory and riches), The colony was once a lush and beautiful land.
Filled with stunning glens and bubbling brooks, everything a person could need was supplied to them.
Any other amnenities were imported through the frequent ships from the empire proper. It truly was a glorius and prosperious life.

But, when the empire withdrew their troops from the colony, the land faced many savage attacks from natives, and quickly fell to disarray.
Many colonists returned to their villages, telling tales of a dead and barren land much unlike the place told of by the emperor.
The colony quickly gained the name "A kétségbeesés gyarmata" (Colony of Despair) in the rest of the empire, with many calls to abandon it
The government, in a last effort to save the colony sent troops back, however, the troops all fell ill and died, despite no visible ailments.
When news reached the emperor, he sent ships to round up the remaining colonists to bring them home. And yet, the colony was empty.
Investigating, they find signs that the colonists had recently been in, with everything being in order.
So, the ships came back empty, with each ship telling tales of freshly abandoned villages, the colony was abandoned, and funds redirected to more colonies.

The few colonists who returned early on tell tales of demonic and savage natives worshipping different gods who seem to give them "gifts"
The savages supposedly have abilities unlike those of any known to the Empire, their gods sinister and cruel, longing for flesh and blood.
But, are these the stories of truth? Or tales thought by the weary mind of a scarred body?